Module attribute

Defines functionalitie associated with vertex attributes and their respective layouts and formats.

Structs

Nor
Represents values that, when passed to shaders as vertex attributes, are to be treated as normalized floating point numbers. For example, [u8; 2]’s format is VertexFormat::Uint8x2, while [Nor<u8>; 2]’s format is VertexFormat::Unorm8x2.

Traits

IsVertexAttribute
Marks the type as acceptable by shader programs as vertex attributes. You shouldn’t implement this manually, as this crate already does that for you.
LinearRgbaExt
Extension trait for LinearRgba.
VertexLayout
Represents vertex values in a vertex buffer object.

Derive Macros

VertexLayout
Derives VertexLayout. Note that this also requires NoUninit, which you can derive with hephae-render’s re-export: #[bytemuck(crate = "hephae::render::bytemuck")].