Struct Nor

#[repr(transparent)]
pub struct Nor<T>(pub T);
Represents values that, when passed to shaders as vertex attributes, are to be treated as normalized floating point numbers. For example, [u8; 2]’s format is VertexFormat::Uint8x2, while [Nor<u8>; 2]’s format is VertexFormat::Unorm8x2.

Tuple Fields

0: T