Module image_bind

Utilities to store and keep track of Images as BindGroups in the render world.

See examples/atlas.rs for example usage.

Structs

ImageAssetEvents
Extracts AssetEvent<Image>s from the main world to the render world.
ImageBindGroups
Stores BindGroups for each Image on-demand via create.

Functions

extract_image_events
Populates ImageAssetEvents.
validate_image_bind_groups
For each removed Image, remove the BindGroup in ImageBindGroups too.