Trait VertexConf

pub trait VertexConf {
    // Required method
    fn build(builder: PluginGroupBuilder) -> PluginGroupBuilder;
}
Vertexs you can pass to render to conveniently configure them in one go.

Required Methods

fn build(builder: PluginGroupBuilder) -> PluginGroupBuilder

Configures the plugin group builder for the types contained in this parameter type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl VertexConf for ()

Source

impl<T1: VertexConf> VertexConf for (T1₁, T1₂, …, T1ₙ)

Implementors

Source

impl<T: Vertex> VertexConf for T