pub unsafe trait IsVertexAttribute: Pod {
const FORMAT: VertexFormat;
}Expand description
Marks the type as acceptable by shader programs as vertex attributes. You shouldn’t implement this manually, as this crate already does that for you.
Safety
Required Associated Constants
Sourceconst FORMAT: VertexFormat
const FORMAT: VertexFormat
The associated vertex format of this vertex attribute.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.